@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2015-05-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -181,14 +181,14 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.02 of App::dateseq (from Perl distribution App-dateseq), released on 2015-05-13.
+This document describes version 0.03 of App::dateseq (from Perl distribution App-dateseq), released on 2015-08-18.
 
 =head1 FUNCTIONS
 
 
 =head2 dateseq(%args) -> [status, msg, result, meta]
 
-Generate a sequence of dates.
+{en_US Generate a sequence of dates}.
 
 Examples:
 
@@ -234,8 +234,10 @@ List non-holidays business days in 2015 (using Indonesian holidays).
 Use with fsql.
 
 
+{en_US 
 This utility is similar to Unix C<seq> command, except that it generates a
 sequence of dates.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -243,33 +245,33 @@ Arguments ('*' denotes required arguments):
 
 =item * B<business> => I<bool>
 
-Only list business days (Mon-Fri).
+{en_US Only list business days (Mon-Fri)}.
 
 =item * B<business6> => I<bool>
 
-Only list business days (Mon-Sat).
+{en_US Only list business days (Mon-Sat)}.
 
 =item * B<date_format> => I<str>
 
-strftime() format for each date.
+{en_US strftime() format for each date}.
 
 =item * B<from>* => I<date>
 
-Starting date.
+{en_US Starting date}.
 
 =item * B<header> => I<str>
 
-Add a header row.
+{en_US Add a header row}.
 
 =item * B<increment> => I<duration>
 
 =item * B<limit> => I<int>
 
-Only generate a certain amount of numbers.
+{en_US Only generate a certain amount of numbers}.
 
 =item * B<to> => I<date>
 
-End date, if not specified will generate an infinite* stream of dates.
+{en_US End date, if not specified will generate an infinite* stream of dates}.
 
 =back
 
